@@ -1,7 +1,7 @@
 package Complete::Man;
 
-our $DATE = '2016-10-15'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-10-20'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,7 +28,7 @@ sub _complete_manpage_or_section {
 
     my $sect = $args{section};
     if (defined $sect) {
-        $sect = "man$sect" unless $sect =~ /\Aman/;
+        $sect = [map {/\Aman/ ? $_ : "man$_"} split /\s*,\s*/, $sect];
     }
 
     return [] unless $ENV{MANPATH};
@@ -42,7 +42,7 @@ sub _complete_manpage_or_section {
         opendir my($dh), $dir or next;
         for my $sectdir (readdir $dh) {
             next unless $sectdir =~ /\Aman/;
-            next if $sect && $sect ne $sectdir;
+            next if $sect && !grep {$sectdir eq $_} @$sect;
             opendir my($dh), "$dir/$sectdir" or next;
             my @files = readdir($dh);
             for my $file (@files) {
@@ -89,8 +89,13 @@ _
             pos => 0,
         },
         section => {
-            summary => 'Only search from this section',
+            summary => 'Only search from specified section(s)',
             schema  => 'str*',
+            description => <<'_',
+
+Can also be a comma-separated list to allow multiple sections.
+
+_
         },
     },
     result_naked => 1,
@@ -124,7 +129,7 @@ sub complete_manpage_section {
 }
 
 1;
-# ABSTRACT: Complete from list of available manpage sections
+# ABSTRACT: Complete from list of available manpages
 
 __END__
 
@@ -134,11 +139,11 @@ __END__
 
 =head1 NAME
 
-Complete::Man - Complete from list of available manpage sections
+Complete::Man - Complete from list of available manpages
 
 =head1 VERSION
 
-This document describes version 0.06 of Complete::Man (from Perl distribution Complete-Man), released on 2016-10-15.
+This document describes version 0.07 of Complete::Man (from Perl distribution Complete-Man), released on 2016-10-20.
 
 =head1 SYNOPSIS
 
@@ -173,7 +178,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<section> => I<str>
 
-Only search from this section.
+Only search from specified section(s).
+
+Can also be a comma-separated list to allow multiple sections.
 
 =item * B<word>* => I<str>
 
